<?php
/**
 * @brief Samsung client devices specific methods
 * @details Engine / Tool Library
 * @author CaMykS Team <camyks.contact@gmail.com>
 * @version 1.0.107
 * @date Creation: Apr 2018
 * @date Modification: Mar 2023
 * @copyright 2018 - 2023 CaMykS Team
 * @note This program is distributed as is - WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * @warning This library is not loaded with CaMykS initialisation.
 */

/**
 * Return Samsung client device information from a known list.
 * @param mixed $deviceCode
 * @return array
 */
function get_SamsungClientDevice($deviceCode='') {
    $deviceList = array(

        /* Samsung Galaxy View series */
        'SM-T670'   => array('platform_model' => 'Galaxy View',         'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),

        /* Samsung Galaxy Tab series */
        'GT-P1000'  => array('platform_model' => 'Galaxy Tab',          'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2010),
        'GT-P1000M' => array('platform_model' => 'Galaxy Tab',          'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2010),
        'GT-P7510'  => array('platform_model' => 'Galaxy Tab 10.1',     'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2011),
        'GT-P3100'  => array('platform_model' => 'Galaxy Tab 2',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2012),
        'GT-P3110'  => array('platform_model' => 'Galaxy Tab 2',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2012),
        'GT-P5100'  => array('platform_model' => 'Galaxy Tab 2',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2012),
        'GT-P5110'  => array('platform_model' => 'Galaxy Tab 2',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2012),
        'GT-P5200'  => array('platform_model' => 'Galaxy Tab 3',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2013),
        'GT-P5210'  => array('platform_model' => 'Galaxy Tab 3',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2013),
        'GT-P5220'  => array('platform_model' => 'Galaxy Tab 3',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2013),
        'GT-P7300'  => array('platform_model' => 'Galaxy Tab 8.9',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2011),
        'SM-T110'   => array('platform_model' => 'Galaxy Tab 3 Lite',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T113'   => array('platform_model' => 'Galaxy Tab 3 Lite',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T217S'  => array('platform_model' => 'Galaxy Tab 3 7.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2013),
        'SM-T210R'  => array('platform_model' => 'Galaxy Tab 3 7.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2013),
        'SM-T310'   => array('platform_model' => 'Galaxy Tab 3',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2013),
        'SM-T113NU' => array('platform_model' => 'Galaxy Tab 3 V',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T116NU' => array('platform_model' => 'Galaxy Tab 3 V',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T320'   => array('platform_model' => 'Galaxy Tab Pro',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T520'   => array('platform_model' => 'Galaxy Tab Pro',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T230'   => array('platform_model' => 'Galaxy Tab 4',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T230NU' => array('platform_model' => 'Galaxy Tab 4',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T237P'  => array('platform_model' => 'Galaxy Tab 4 7.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T330NU' => array('platform_model' => 'Galaxy Tab 4 10.1',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T530'   => array('platform_model' => 'Galaxy Tab 4',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T530NU' => array('platform_model' => 'Galaxy Tab 4',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T531'   => array('platform_model' => 'Galaxy Tab 4 (3G)',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T533'   => array('platform_model' => 'Galaxy Tab 4',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T535'   => array('platform_model' => 'Galaxy Tab 4 (4G)',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T325'   => array('platform_model' => 'Galaxy Tab 8.4',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T900'   => array('platform_model' => 'Galaxy Tab Pro 12.2', 'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T350'   => array('platform_model' => 'Galaxy Tab A 8.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T390'   => array('platform_model' => 'Galaxy Tab Active 2', 'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2017),
        'SM-T550'   => array('platform_model' => 'Galaxy Tab A',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-P550'   => array('platform_model' => 'Galaxy Tab A',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T555'   => array('platform_model' => 'Galaxy Tab A 9.7',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T280'   => array('platform_model' => 'Galaxy Tab A 7.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-T285'   => array('platform_model' => 'Galaxy Tab A 7.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-T290'   => array('platform_model' => 'Galaxy Tab A 8.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2019),
        'SM-T295'   => array('platform_model' => 'Galaxy Tab A 8.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2019),
        'SM-T380'   => array('platform_model' => 'Galaxy Tab A 8.0',    'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T510'   => array('platform_model' => 'Galaxy Tab A 10.1',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2019),
        'SM-T515'   => array('platform_model' => 'Galaxy Tab A 10.1',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2019),
        'SM-P580'   => array('platform_model' => 'Galaxy Tab A 10.1',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-T585'   => array('platform_model' => 'Galaxy Tab A 10.1',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-T585'   => array('platform_model' => 'Galaxy Tab A 10.1',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-P585M'  => array('platform_model' => 'Galaxy Tab A 10.1',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-P585Y'  => array('platform_model' => 'Galaxy Tab A 10.1',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-T590'   => array('platform_model' => 'Galaxy Tab A 10.5',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2018),
        'SM-T595'   => array('platform_model' => 'Galaxy Tab A 10.5',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2018),
        'SM-T560'   => array('platform_model' => 'Galaxy Tab E',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T560NU' => array('platform_model' => 'Galaxy Tab E',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T561'   => array('platform_model' => 'Galaxy Tab E',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T580'   => array('platform_model' => 'Galaxy Tab S8',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-T700'   => array('platform_model' => 'Galaxy Tab S',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T800'   => array('platform_model' => 'Galaxy Tab S',        'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2014),
        'SM-T710'   => array('platform_model' => 'Galaxy Tab S2 8.0',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T715'   => array('platform_model' => 'Galaxy Tab S2 8.0',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T719'   => array('platform_model' => 'Galaxy Tab S2 8.0',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T810'   => array('platform_model' => 'Galaxy Tab S2 9.7',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T815'   => array('platform_model' => 'Galaxy Tab S2 9.7',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T819'   => array('platform_model' => 'Galaxy Tab S2 9.7',   'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2015),
        'SM-T713'   => array('platform_model' => 'Galaxy Tab S2',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-T813'   => array('platform_model' => 'Galaxy Tab S2',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2016),
        'SM-T820'   => array('platform_model' => 'Galaxy Tab S3',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2017),
        'SM-T825'   => array('platform_model' => 'Galaxy Tab S3',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2017),
        'SM-T830'   => array('platform_model' => 'Galaxy Tab S4',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2018),
        'SM-T835'   => array('platform_model' => 'Galaxy Tab S4',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2018),
        'SM-T835N'  => array('platform_model' => 'Galaxy Tab S4',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2018),
        'SM-T720'   => array('platform_model' => 'Galaxy Tab S5e',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2019),
        'SM-T725'   => array('platform_model' => 'Galaxy Tab S5e',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2019),
        'SM-T860'   => array('platform_model' => 'Galaxy Tab S6',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2019),
        'SM-T865'   => array('platform_model' => 'Galaxy Tab S6',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2019),
        'SM-T500'   => array('platform_model' => 'Galaxy Tab A7 10.4',  'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2020),
        'SM-T505'   => array('platform_model' => 'Galaxy Tab A7 10.4',  'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2020),
        'SM-P610'   => array('platform_model' => 'Galaxy Tab S6 Light', 'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2020),
        'SM-P615'   => array('platform_model' => 'Galaxy Tab S6 Light', 'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2020),
        'SM-T870'   => array('platform_model' => 'Galaxy Tab S7',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2020),
        'SM-T875'   => array('platform_model' => 'Galaxy Tab S7',       'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2020),
        'SM-T970'   => array('platform_model' => 'Galaxy Tab S7+',      'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2020),
        'SM-T575'   => array('platform_model' => 'Galaxy Tab Active 3', 'platform_type' => 'tablet',    'platform_format' => 'tablet',  'platform_year' => 2020),

        /* Samsung Galaxy S series */
        'GT-I9000'  => array('platform_model' => 'Galaxy S',                        'platform_year' => 2010),
        'GT-S7562'  => array('platform_model' => 'Galaxy S Duo',                    'platform_year' => 2012),
        'GT-S7568'  => array('platform_model' => 'Galaxy S Duo',                    'platform_year' => 2012),
        'GT-I9100'  => array('platform_model' => 'Galaxy S2',                       'platform_year' => 2011),
        'GT-I9105P' => array('platform_model' => 'Galaxy S2 Plus',                  'platform_year' => 2013),
        'GT-I9300'  => array('platform_model' => 'Galaxy S3',                       'platform_year' => 2012),
        'GT-I9305'  => array('platform_model' => 'Galaxy S3 (4G)',                  'platform_year' => 2012),
        'GT-I9301I' => array('platform_model' => 'Galaxy S3 Neo',                   'platform_year' => 2014),
        'GT-I8190'  => array('platform_model' => 'Galaxy S3 Mini',                  'platform_year' => 2012),
        'GT-I8190N' => array('platform_model' => 'Galaxy S3 Mini',                  'platform_year' => 2012),
        'GT-I8200N' => array('platform_model' => 'Galaxy S3 Mini',                  'platform_year' => 2012),
        'SM-G730W8' => array('platform_model' => 'Galaxy S3 Mini',                  'platform_year' => 2012),
        'GT-I9500'  => array('platform_model' => 'Galaxy S4',                       'platform_year' => 2013),
        'GT-I9505'  => array('platform_model' => 'Galaxy S4',                       'platform_year' => 2013),
        'GT-I9506'  => array('platform_model' => 'Galaxy S4',                       'platform_year' => 2013),
        'GT-I9515'  => array('platform_model' => 'Galaxy S4',                       'platform_year' => 2013),
        'SGH-I337'  => array('platform_model' => 'Galaxy S4',                       'platform_year' => 2013),
        'SGH-I337M' => array('platform_model' => 'Galaxy S4',                       'platform_year' => 2013),
        'SPH-L720'  => array('platform_model' => 'Galaxy S4',                       'platform_year' => 2013),
        'GT-I9195I' => array('platform_model' => 'Galaxy S4 Mini',                  'platform_year' => 2013),
        'GT-I9195'  => array('platform_model' => 'Galaxy S4 Mini',                  'platform_year' => 2013),
        'GT-I9192'  => array('platform_model' => 'Galaxy S4 Mini Duos',             'platform_year' => 2013),
        'GT-I9295'  => array('platform_model' => 'Galaxy S4 Active',                'platform_year' => 2013),
        'SM-G900A'  => array('platform_model' => 'Galaxy S5',                       'platform_year' => 2014),
        'SM-G900F'  => array('platform_model' => 'Galaxy S5',                       'platform_year' => 2014),
        'SM-G900P'  => array('platform_model' => 'Galaxy S5',                       'platform_year' => 2014),
        'SM-G900T'  => array('platform_model' => 'Galaxy S5',                       'platform_year' => 2014),
        'SM-G900V'  => array('platform_model' => 'Galaxy S5',                       'platform_year' => 2014),
        'SM-G900W8' => array('platform_model' => 'Galaxy S5',                       'platform_year' => 2014),
        'SM-G901F'  => array('platform_model' => 'Galaxy S5+',                      'platform_year' => 2014),
        'SM-G800F'  => array('platform_model' => 'Galaxy S5 Mini',                  'platform_year' => 2014),
        'SM-G800H'  => array('platform_model' => 'Galaxy S5 Mini',                  'platform_year' => 2014),
        'SM-G870A'  => array('platform_model' => 'Galaxy S5 Active',                'platform_year' => 2014),
        'SM-G870F'  => array('platform_model' => 'Galaxy S5 Active',                'platform_year' => 2014),
        'SM-G903F'  => array('platform_model' => 'Galaxy S5 Neo',                   'platform_year' => 2015),
        'SM-G903W'  => array('platform_model' => 'Galaxy S5 Neo',                   'platform_year' => 2015),
        'SM-G920A'  => array('platform_model' => 'Galaxy S6',                       'platform_year' => 2015),
        'SM-G920F'  => array('platform_model' => 'Galaxy S6',                       'platform_year' => 2015),
        'SM-G920I'  => array('platform_model' => 'Galaxy S6',                       'platform_year' => 2015),
        'SM-G920P'  => array('platform_model' => 'Galaxy S6',                       'platform_year' => 2015),
        'SM-G920T'  => array('platform_model' => 'Galaxy S6',                       'platform_year' => 2015),
        'SM-G920V'  => array('platform_model' => 'Galaxy S6',                       'platform_year' => 2015),
        'SM-G920W8' => array('platform_model' => 'Galaxy S6',                       'platform_year' => 2015),
        'SM-G925F'  => array('platform_model' => 'Galaxy S6 Edge',                  'platform_year' => 2015),
        'SM-G925I'  => array('platform_model' => 'Galaxy S6 Edge',                  'platform_year' => 2015),
        'SM-G925P'  => array('platform_model' => 'Galaxy S6 Edge',                  'platform_year' => 2015),
        'SM-G925T'  => array('platform_model' => 'Galaxy S6 Edge',                  'platform_year' => 2015),
        'SM-G925W8' => array('platform_model' => 'Galaxy S6 Edge',                  'platform_year' => 2015),
        'SC-04G'    => array('platform_model' => 'Galaxy S6 Edge',                  'platform_year' => 2015),
        'SM-G928A'  => array('platform_model' => 'Galaxy S6 Edge+',                 'platform_year' => 2015),
        'SM-G928C'  => array('platform_model' => 'Galaxy S6 Edge+',                 'platform_year' => 2015),
        'SM-G928F'  => array('platform_model' => 'Galaxy S6 Edge+',                 'platform_year' => 2015),
        'SM-G891A'  => array('platform_model' => 'Galaxy S7 Active',                'platform_year' => 2016),
        'SM-G930'   => array('platform_model' => 'Galaxy S7',                       'platform_year' => 2016),
        'SM-G930A'  => array('platform_model' => 'Galaxy S7',                       'platform_year' => 2016),
        'SM-G930F'  => array('platform_model' => 'Galaxy S7',                       'platform_year' => 2016),
        'SM-G930S'  => array('platform_model' => 'Galaxy S7',                       'platform_year' => 2016),
        'SM-G930T'  => array('platform_model' => 'Galaxy S7',                       'platform_year' => 2016),
        'SM-G930U'  => array('platform_model' => 'Galaxy S7',                       'platform_year' => 2016),
        'SM-G930V'  => array('platform_model' => 'Galaxy S7',                       'platform_year' => 2016),
        'SM-G930W8' => array('platform_model' => 'Galaxy S7',                       'platform_year' => 2016),
        'SM-G935'   => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G9350'  => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G935A'  => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G935F'  => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G935K'  => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G935P'  => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G935T'  => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G935U'  => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G935V'  => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G935W8' => array('platform_model' => 'Galaxy S7 Edge',                  'platform_year' => 2016),
        'SM-G950'   => array('platform_model' => 'Galaxy S8',                       'platform_year' => 2017),
        'SM-G9500'  => array('platform_model' => 'Galaxy S8',                       'platform_year' => 2017),
        'SM-G950F'  => array('platform_model' => 'Galaxy S8',                       'platform_year' => 2017),
        'SM-G950U'  => array('platform_model' => 'Galaxy S8',                       'platform_year' => 2017),
        'SM-G950U1' => array('platform_model' => 'Galaxy S8',                       'platform_year' => 2017),
        'SM-G950W'  => array('platform_model' => 'Galaxy S8',                       'platform_year' => 2017),
        'SM-G9550'  => array('platform_model' => 'Galaxy S8+',                      'platform_year' => 2017),
        'SM-G955F'  => array('platform_model' => 'Galaxy S8+',                      'platform_year' => 2017),
        'SM-G955N'  => array('platform_model' => 'Galaxy S8+',                      'platform_year' => 2017),
        'SM-G955U'  => array('platform_model' => 'Galaxy S8+',                      'platform_year' => 2017),
        'SM-G955U1' => array('platform_model' => 'Galaxy S8+',                      'platform_year' => 2017),
        'SM-G955W'  => array('platform_model' => 'Galaxy S8+',                      'platform_year' => 2017),
        'SM-G892A'  => array('platform_model' => 'Galaxy S8 Active',                'platform_year' => 2017),
        'SM-G892U'  => array('platform_model' => 'Galaxy S8 Active',                'platform_year' => 2017),
        'SM-G9600'  => array('platform_model' => 'Galaxy S9',                       'platform_year' => 2018),
        'SM-G960F'  => array('platform_model' => 'Galaxy S9',                       'platform_year' => 2018),
        'SM-G960N'  => array('platform_model' => 'Galaxy S9',                       'platform_year' => 2018),
        'SM-G960U1' => array('platform_model' => 'Galaxy S9',                       'platform_year' => 2018),
        'SM-G960U'  => array('platform_model' => 'Galaxy S9',                       'platform_year' => 2018),
        'SM-G960W'  => array('platform_model' => 'Galaxy S9',                       'platform_year' => 2018),
        'SM-G9650'  => array('platform_model' => 'Galaxy S9+',                      'platform_year' => 2018),
        'SM-G965F'  => array('platform_model' => 'Galaxy S9+',                      'platform_year' => 2018),
        'SM-G965U'  => array('platform_model' => 'Galaxy S9+',                      'platform_year' => 2018),
        'SM-G965U1' => array('platform_model' => 'Galaxy S9+',                      'platform_year' => 2018),
        'SM-G965W'  => array('platform_model' => 'Galaxy S9+',                      'platform_year' => 2018),
        'SM-G9700'  => array('platform_model' => 'Galaxy S10E',                     'platform_year' => 2019),
        'SM-G970F'  => array('platform_model' => 'Galaxy S10E',                     'platform_year' => 2019),
        'SM-G970U'  => array('platform_model' => 'Galaxy S10E',                     'platform_year' => 2019),
        'SM-G970U1' => array('platform_model' => 'Galaxy S10E',                     'platform_year' => 2019),
        'SM-G970W'  => array('platform_model' => 'Galaxy S10E',                     'platform_year' => 2019),
        'SM-G9730'  => array('platform_model' => 'Galaxy S10',                      'platform_year' => 2019),
        'SM-G973F'  => array('platform_model' => 'Galaxy S10',                      'platform_year' => 2019),
        'SM-G973N'  => array('platform_model' => 'Galaxy S10',                      'platform_year' => 2019),
        'SM-G973W'  => array('platform_model' => 'Galaxy S10',                      'platform_year' => 2019),
        'SM-G9750'  => array('platform_model' => 'Galaxy S10+',                     'platform_year' => 2019),
        'SM-G975F'  => array('platform_model' => 'Galaxy S10+',                     'platform_year' => 2019),
        'SM-G975U'  => array('platform_model' => 'Galaxy S10+',                     'platform_year' => 2019),
        'SM-G975U1' => array('platform_model' => 'Galaxy S10+',                     'platform_year' => 2019),
        'SM-G975W'  => array('platform_model' => 'Galaxy S10+',                     'platform_year' => 2019),
        'SM-G977B'  => array('platform_model' => 'Galaxy S10 5G',                   'platform_year' => 2019),
        'SM-G977N'  => array('platform_model' => 'Galaxy S10 5G',                   'platform_year' => 2019),
        'SM-G770F'  => array('platform_model' => 'Galaxy S10 Lite',                 'platform_year' => 2019),
        'SM-G980F'  => array('platform_model' => 'Galaxy S20',                      'platform_year' => 2020),
        'SM-G9810'  => array('platform_model' => 'Galaxy S20',                      'platform_year' => 2020),
        'SM-G981B'  => array('platform_model' => 'Galaxy S20',                      'platform_year' => 2020),
        'SM-G981W'  => array('platform_model' => 'Galaxy S20 5G',                   'platform_year' => 2020),
        'SM-G985F'  => array('platform_model' => 'Galaxy S20+',                     'platform_year' => 2020),
        'SM-G986B'  => array('platform_model' => 'Galaxy S20+',                     'platform_year' => 2020),
        'SM-G9860'  => array('platform_model' => 'Galaxy S20+ 5G',                  'platform_year' => 2020),
        'SM-G986U'  => array('platform_model' => 'Galaxy S20+ 5G',                  'platform_year' => 2020),
        'SM-G9880'  => array('platform_model' => 'Galaxy S20 Ultra',                'platform_year' => 2020),
        'SM-G988B'  => array('platform_model' => 'Galaxy S20 Ultra',                'platform_year' => 2020),
        'SM-G988N'  => array('platform_model' => 'Galaxy S20 Ultra',                'platform_year' => 2020),
        'SM-G988U'  => array('platform_model' => 'Galaxy S20 Ultra',                'platform_year' => 2020),
        'SM-G780F'  => array('platform_model' => 'Galaxy S20 Fan Edition',          'platform_year' => 2020),
        'SM-G780G'  => array('platform_model' => 'Galaxy S20 Fan Edition',          'platform_year' => 2020),
        'SM-G781B'  => array('platform_model' => 'Galaxy S20 Fan Edition',          'platform_year' => 2020),
        'SM-G990B'  => array('platform_model' => 'Galaxy S21 FE',                   'platform_year' => 2021),
        'SM-G9910'  => array('platform_model' => 'Galaxy S21 5G',                   'platform_year' => 2021),
        'SM-G991B'  => array('platform_model' => 'Galaxy S21',                      'platform_year' => 2021),
        'SM-G991W'  => array('platform_model' => 'Galaxy S21',                      'platform_year' => 2021),
        'SM-G996B'  => array('platform_model' => 'Galaxy S21+ 5G',                  'platform_year' => 2021),
        'SM-G9980'  => array('platform_model' => 'Galaxy S21 Ultra 5G',             'platform_year' => 2021),
        'SM-G998B'  => array('platform_model' => 'Galaxy S21 Ultra',                'platform_year' => 2021),
        'SM-S901B'  => array('platform_model' => 'Galaxy S22',                      'platform_year' => 2022),

        /* Samsung Galaxy A series */
        'SM-A015M'  => array('platform_model' => 'Galaxy A01',                      'platform_year' => 2020),
        'SM-A022DS' => array('platform_model' => 'Galaxy A02 Premium Edition',      'platform_year' => 2021),
        'SM-A022G'  => array('platform_model' => 'Galaxy A02 Premium Edition',      'platform_year' => 2021),
        'SM-A022M'  => array('platform_model' => 'Galaxy A02',                      'platform_year' => 2021),
        'SM-A025F'  => array('platform_model' => 'Galaxy A02s',                     'platform_year' => 2020),
        'SM-A025G'  => array('platform_model' => 'Galaxy A02s',                     'platform_year' => 2021),
        'SM-A260F'  => array('platform_model' => 'Galaxy A2 Core',                  'platform_year' => 2019),
        'SM-A260G'  => array('platform_model' => 'Galaxy A2 Core',                  'platform_year' => 2019),
        'SM-A300F'  => array('platform_model' => 'Galaxy A3',                       'platform_year' => 2014),
        'SM-A300FU' => array('platform_model' => 'Galaxy A3',                       'platform_year' => 2014),
        'SM-A310F'  => array('platform_model' => 'Galaxy A3',                       'platform_year' => 2015),
        'SM-A300M'  => array('platform_model' => 'Galaxy A3',                       'platform_year' => 2014),
        'SM-A320L'  => array('platform_model' => 'Galaxy A3',                       'platform_year' => 2017),
        'SM-A320F'  => array('platform_model' => 'Galaxy A3',                       'platform_year' => 2017),
        'SM-A320FL' => array('platform_model' => 'Galaxy A3',                       'platform_year' => 2017),
        'SM-A320Y'  => array('platform_model' => 'Galaxy A3',                       'platform_year' => 2017),
        'SM-A5000'  => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2014),
        'SM-A500F'  => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2014),
        'SM-A500H'  => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2014),
        'SM-A500W'  => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2014),
        'SM-A500FU' => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2015),
        'SM-A510'   => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2016),
        'SM-A510F'  => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2016),
        'SM-A5100'  => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2016),
        'SM-A520F'  => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2017),
        'SM-A520W'  => array('platform_model' => 'Galaxy A5',                       'platform_year' => 2017),
        'SM-A600FN' => array('platform_model' => 'Galaxy A6',                       'platform_year' => 2018),
        'SM-A600F'  => array('platform_model' => 'Galaxy A6',                       'platform_year' => 2018),
        'SM-A600G'  => array('platform_model' => 'Galaxy A6',                       'platform_year' => 2018),
        'SM-A605F'  => array('platform_model' => 'Galaxy A6+',                      'platform_year' => 2018),
        'SM-A605FN' => array('platform_model' => 'Galaxy A6+',                      'platform_year' => 2018),
        'SM-A7000'  => array('platform_model' => 'Galaxy A7',                       'platform_year' => 2015),
        'SM-A700F'  => array('platform_model' => 'Galaxy A7',                       'platform_year' => 2015),
        'SM-A700L'  => array('platform_model' => 'Galaxy A7',                       'platform_year' => 2015),
        'SM-A7100'  => array('platform_model' => 'Galaxy A7',                       'platform_year' => 2015),
        'SM-A720F'  => array('platform_model' => 'Galaxy A7',                       'platform_year' => 2017),
        'SM-A750F'  => array('platform_model' => 'Galaxy A7',                       'platform_year' => 2018),
        'SM-A750FN' => array('platform_model' => 'Galaxy A7',                       'platform_year' => 2018),
        'SM-A750GN' => array('platform_model' => 'Galaxy A7',                       'platform_year' => 2018),
        'SM-A800I'  => array('platform_model' => 'Galaxy A8',                       'platform_year' => 2015),
        'SM-A530F'  => array('platform_model' => 'Galaxy A8',                       'platform_year' => 2018),
        'SM-A530W'  => array('platform_model' => 'Galaxy A8',                       'platform_year' => 2018),
        'SM-A730F'  => array('platform_model' => 'Galaxy A8+',                      'platform_year' => 2018),
        'SM-A900F'  => array('platform_model' => 'Galaxy A9',                       'platform_year' => 2016),
        'SM-A910F'  => array('platform_model' => 'Galaxy A9 Pro',                   'platform_year' => 2016),
        'SM-A920F'  => array('platform_model' => 'Galaxy A9',                       'platform_year' => 2018),
        'SM-A105F'  => array('platform_model' => 'Galaxy A10',                      'platform_year' => 2019),
        'SM-A105FN' => array('platform_model' => 'Galaxy A10',                      'platform_year' => 2019),
        'SM-A105G'  => array('platform_model' => 'Galaxy A10',                      'platform_year' => 2019),
        'SM-A105M'  => array('platform_model' => 'Galaxy A10',                      'platform_year' => 2019),
        'SM-A102U'  => array('platform_model' => 'Galaxy A10e',                     'platform_year' => 2019),
        'SM-A102W'  => array('platform_model' => 'Galaxy A10e',                     'platform_year' => 2019),
        'SM-A107F'  => array('platform_model' => 'Galaxy A10S',                     'platform_year' => 2019),
        'SM-A107M'  => array('platform_model' => 'Galaxy A10S',                     'platform_year' => 2019),
        'SM-A115F'  => array('platform_model' => 'Galaxy A11',                      'platform_year' => 2020),
        'SM-A125F'  => array('platform_model' => 'Galaxy A12',                      'platform_year' => 2020),
        'SM-A127F'  => array('platform_model' => 'Galaxy A12',                      'platform_year' => 2020),
        'SM-A205F'  => array('platform_model' => 'Galaxy A20',                      'platform_year' => 2019),
        'SM-A205FN' => array('platform_model' => 'Galaxy A20',                      'platform_year' => 2019),
        'SM-A205G'  => array('platform_model' => 'Galaxy A20',                      'platform_year' => 2019),
        'SM-A205GN' => array('platform_model' => 'Galaxy A20',                      'platform_year' => 2019),
        'SM-A205U'  => array('platform_model' => 'Galaxy A20',                      'platform_year' => 2019),
        'SM-A205W'  => array('platform_model' => 'Galaxy A20',                      'platform_year' => 2019),
        'SM-A202F'  => array('platform_model' => 'Galaxy A20e',                     'platform_year' => 2019),
        'SM-A207F'  => array('platform_model' => 'Galaxy A20s',                     'platform_year' => 2019),
        'SM-A207M'  => array('platform_model' => 'Galaxy A20s',                     'platform_year' => 2019),
        'SM-A215W'  => array('platform_model' => 'Galaxy A21',                      'platform_year' => 2020),
        'SM-A217F'  => array('platform_model' => 'Galaxy A21s',                     'platform_year' => 2019),
        'SM-A225F'  => array('platform_model' => 'Galaxy A22',                      'platform_year' => 2020),
        'SM-A226B'  => array('platform_model' => 'Galaxy A22 5G',                   'platform_year' => 2020),
        'SM-A305F'  => array('platform_model' => 'Galaxy A30',                      'platform_year' => 2019),
        'SM-A305FN' => array('platform_model' => 'Galaxy A30',                      'platform_year' => 2019),
        'SM-A305G'  => array('platform_model' => 'Galaxy A30',                      'platform_year' => 2019),
        'SM-A305GT' => array('platform_model' => 'Galaxy A30',                      'platform_year' => 2019),
        'SM-A307FN' => array('platform_model' => 'Galaxy A30s',                     'platform_year' => 2019),
        'SM-A307GN' => array('platform_model' => 'Galaxy A30s',                     'platform_year' => 2019),
        'SM-A315F'  => array('platform_model' => 'Galaxy A31',                      'platform_year' => 2020),
        'SM-A315G'  => array('platform_model' => 'Galaxy A31',                      'platform_year' => 2020),
        'SM-A325F'  => array('platform_model' => 'Galaxy A32',                      'platform_year' => 2021),
        'SM-A326B'  => array('platform_model' => 'Galaxy A32 5G',                   'platform_year' => 2021),
        'SM-A405FN' => array('platform_model' => 'Galaxy A40',                      'platform_year' => 2019),
        'SM-A3050'  => array('platform_model' => 'Galaxy A40s',                     'platform_year' => 2019),
        'SM-A415F'  => array('platform_model' => 'Galaxy A41',                      'platform_year' => 2020),
        'SM-A426B'  => array('platform_model' => 'Galaxy A42',                      'platform_year' => 2020),
        'SM-A505F'  => array('platform_model' => 'Galaxy A50',                      'platform_year' => 2019),
        'SM-A505FN' => array('platform_model' => 'Galaxy A50',                      'platform_year' => 2019),
        'SM-A505G'  => array('platform_model' => 'Galaxy A50',                      'platform_year' => 2019),
        'SM-A505GN' => array('platform_model' => 'Galaxy A50',                      'platform_year' => 2019),
        'SM-A505W'  => array('platform_model' => 'Galaxy A50',                      'platform_year' => 2019),
        'SM-A5070'  => array('platform_model' => 'Galaxy A50s',                     'platform_year' => 2019),
        'SM-A507FN' => array('platform_model' => 'Galaxy A50s',                     'platform_year' => 2019),
        'SM-A515F'  => array('platform_model' => 'Galaxy A51',                      'platform_year' => 2019),
        'SM-A515W'  => array('platform_model' => 'Galaxy A51',                      'platform_year' => 2019),
        'SM-A516B'  => array('platform_model' => 'Galaxy A51 5G',                   'platform_year' => 2020),
        'SM-A526B'  => array('platform_model' => 'Galaxy A52 5G',                   'platform_year' => 2020),
        'SM-A525F'  => array('platform_model' => 'Galaxy A52',                      'platform_year' => 2021),
        'SM-A528B'  => array('platform_model' => 'Galaxy A52s 5G',                  'platform_year' => 2021),
        'SM-A7050'  => array('platform_model' => 'Galaxy A70',                      'platform_year' => 2019),
        'SM-A6060'  => array('platform_model' => 'Galaxy A60',                      'platform_year' => 2019),
        'SM-A705FN' => array('platform_model' => 'Galaxy A70',                      'platform_year' => 2019),
        'SM-A705MN' => array('platform_model' => 'Galaxy A70',                      'platform_year' => 2019),
        'SM-A705W'  => array('platform_model' => 'Galaxy A70',                      'platform_year' => 2019),
        'SM-A705YN' => array('platform_model' => 'Galaxy A70',                      'platform_year' => 2019),
        'SM-A715F'  => array('platform_model' => 'Galaxy A71',                      'platform_year' => 2019),
        'SM-A715W'  => array('platform_model' => 'Galaxy A71',                      'platform_year' => 2020),
        'SM-A725F'  => array('platform_model' => 'Galaxy A72',                      'platform_year' => 2021),
        'SM-A805F'  => array('platform_model' => 'Galaxy A80',                      'platform_year' => 2019),
        'SM-A015F'  => array('platform_model' => 'Galaxy A01',                      'platform_year' => 2020),

        /* Samsung Galaxy C series */
        'SM-C9000'  => array('platform_model' => 'Galaxy C9 Pro',                   'platform_year' => 2016),
        'SM-C701F'  => array('platform_model' => 'Galaxy C7 Pro',                   'platform_year' => 2017),

        /* Samsung Galaxy E series */
        'SM-E500F'  => array('platform_model' => 'Galaxy E5',                       'platform_year' => 2015),
        'SM-E500H'  => array('platform_model' => 'Galaxy E5',                       'platform_year' => 2015),
        'SM-E500HQ' => array('platform_model' => 'Galaxy E5',                       'platform_year' => 2015),
        'SM-E500M'  => array('platform_model' => 'Galaxy E5',                       'platform_year' => 2015),
        'SM-E700H'  => array('platform_model' => 'Galaxy E7',                       'platform_year' => 2015),

        /* Samsung Galaxy F series */
        'SM-E625F'  => array('platform_model' => 'Galaxy F62',                      'platform_year' => 2021),

        /* Samsung Galaxy J series */
        'SM-J100F'  => array('platform_model' => 'Galaxy J1',                       'platform_year' => 2015),
        'SM-J100H'  => array('platform_model' => 'Galaxy J1',                       'platform_year' => 2015),
        'SM-J110H'  => array('platform_model' => 'Galaxy J1',                       'platform_year' => 2015),
        'SM-J120F'  => array('platform_model' => 'Galaxy J1',                       'platform_year' => 2016),
        'SM-J120FN' => array('platform_model' => 'Galaxy J1',                       'platform_year' => 2016),
        'SM-J120H'  => array('platform_model' => 'Galaxy J1',                       'platform_year' => 2016),
        'SM-J120G'  => array('platform_model' => 'Galaxy J1',                       'platform_year' => 2016),
        'SM-J105B'  => array('platform_model' => 'Galaxy J1 Mini',                  'platform_year' => 2016),
        'SM-J106H'  => array('platform_model' => 'Galaxy J1 Mini Prime',            'platform_year' => 2016),
        'SM-J111F'  => array('platform_model' => 'Galaxy J1 Ace Neo',               'platform_year' => 2016),
        'SM-J200F'  => array('platform_model' => 'Galaxy J2',                       'platform_year' => 2015),
        'SM-J200G'  => array('platform_model' => 'Galaxy J2',                       'platform_year' => 2015),
        'SM-J200H'  => array('platform_model' => 'Galaxy J2',                       'platform_year' => 2015),
        'SM-J200M'  => array('platform_model' => 'Galaxy J2',                       'platform_year' => 2015),
        'SM-G532G'  => array('platform_model' => 'Galaxy J2 Prime',                 'platform_year' => 2016),
        'SM-G532M'  => array('platform_model' => 'Galaxy J2 Prime',                 'platform_year' => 2016),
        'SM-J250F'  => array('platform_model' => 'Galaxy J2 Pro',                   'platform_year' => 2018),
        'SM-J250Y'  => array('platform_model' => 'Galaxy J2',                       'platform_year' => 2018),
        'SM-J260F'  => array('platform_model' => 'Galaxy J2 Core',                  'platform_year' => 2018),
        'SM-J260FU' => array('platform_model' => 'Galaxy J2 Core',                  'platform_year' => 2020),
        'SM-J260T1' => array('platform_model' => 'Galaxy J2',                       'platform_year' => 2018),
        'SM-J310'   => array('platform_model' => 'Galaxy J3',                       'platform_year' => 2016),
        'SM-J3119'  => array('platform_model' => 'Galaxy J3',                       'platform_year' => 2016),
        'SM-J320FN' => array('platform_model' => 'Galaxy J3',                       'platform_year' => 2016),
        'SM-J320F'  => array('platform_model' => 'Galaxy J3',                       'platform_year' => 2016),
        'SM-J320H'  => array('platform_model' => 'Galaxy J3',                       'platform_year' => 2016),
        'SM-J320W8' => array('platform_model' => 'Galaxy J3',                       'platform_year' => 2016),
        'SM-J327A'  => array('platform_model' => 'Galaxy J3 Express Prime 2',       'platform_year' => 2017),
        'SM-J327T'  => array('platform_model' => 'Galaxy J3 Prime',                 'platform_year' => 2017),
        'SM-J327T1' => array('platform_model' => 'Galaxy J3 Prime',                 'platform_year' => 2017),
        'SM-J327W'  => array('platform_model' => 'Galaxy J3 Prime',                 'platform_year' => 2017),
        'SM-J330G'  => array('platform_model' => 'Galaxy J3 Pro',                   'platform_year' => 2016),
        'SM-J330FN' => array('platform_model' => 'Galaxy J3',                       'platform_year' => 2017),
        'SM-J330F'  => array('platform_model' => 'Galaxy J3',                       'platform_year' => 2017),
        'SM-J400F'  => array('platform_model' => 'Galaxy J4',                       'platform_year' => 2018),
        'SM-J400M'  => array('platform_model' => 'Galaxy J4',                       'platform_year' => 2018),
        'SM-J410F'  => array('platform_model' => 'Galaxy J4 Core',                  'platform_year' => 2018),
        'SM-J415F'  => array('platform_model' => 'Galaxy J4+',                      'platform_year' => 2018),
        'SM-J415FN' => array('platform_model' => 'Galaxy J4+',                      'platform_year' => 2018),
        'SM-J415GN' => array('platform_model' => 'Galaxy J4+',                      'platform_year' => 2018),
        'SM-J500'   => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2015),
        'SM-J500F'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2015),
        'SM-J500FN' => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2015),
        'SM-J500G'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2015),
        'SM-J500Y'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2015),
        'SM-J500M'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2015),
        'SM-J500H'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2015),
        'SM-J5007'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2015),
        'SM-J500M'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2016),
        'SM-J510F'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2016),
        'SM-J510FN' => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2016),
        'SM-J510G'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2016),
        'SM-J510H'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2016),
        'SM-J510M'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2016),
        'SM-J510Y'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2016),
        'SM-G570F'  => array('platform_model' => 'Galaxy J5 Prime',                 'platform_year' => 2016),
        'SM-G570M'  => array('platform_model' => 'Galaxy J5 Prime',                 'platform_year' => 2016),
        'SM-J530F'  => array('platform_model' => 'Galaxy J5',                       'platform_year' => 2017),
        'SM-J600F'  => array('platform_model' => 'Galaxy J6',                       'platform_year' => 2018),
        'SM-J600FN' => array('platform_model' => 'Galaxy J6',                       'platform_year' => 2018),
        'SM-J600G'  => array('platform_model' => 'Galaxy J6',                       'platform_year' => 2018),
        'SM-J610F'  => array('platform_model' => 'Galaxy J6+',                      'platform_year' => 2018),
        'SM-J610FN' => array('platform_model' => 'Galaxy J6+',                      'platform_year' => 2018),
        'SM-J7008'  => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2015),
        'SM-J700F'  => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2015),
        'SM-J700T1' => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2015),
        'SM-J700H'  => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2016),
        'SM-J710F'  => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2016),
        'SM-J710FQ' => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2016),
        'SM-J710MN' => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2016),
        'SM-J710GN' => array('platform_model' => 'Galaxy J7 Duos',                  'platform_year' => 2016),
        'SM-G6100'  => array('platform_model' => 'Galaxy J7 Prime',                 'platform_year' => 2016),
        'SM-G610F'  => array('platform_model' => 'Galaxy J7 Prime',                 'platform_year' => 2016),
        'SM-G610M'  => array('platform_model' => 'Galaxy J7 Prime',                 'platform_year' => 2016),
        'SM-J727T1' => array('platform_model' => 'Galaxy J7 Prime',                 'platform_year' => 2016),
        'SM-J701F'  => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2017),
        'SM-J720F'  => array('platform_model' => 'Galaxy J7 Duo',                   'platform_year' => 2017),
        'SM-J730F'  => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2017),
        'SM-J730GM' => array('platform_model' => 'Galaxy J7',                       'platform_year' => 2017),
        'SM-J727T'  => array('platform_model' => 'Galaxy J7 Prime',                 'platform_year' => 2017),
        'SM-G615F'  => array('platform_model' => 'Galaxy J7 Max',                   'platform_year' => 2017),
        'SM-G611F'  => array('platform_model' => 'Galaxy J7 Prime 2',               'platform_year' => 2018),
        'SM-J810F'  => array('platform_model' => 'Galaxy J8',                       'platform_year' => 2018),
        'SM-J810G'  => array('platform_model' => 'Galaxy J8',                       'platform_year' => 2018),
        'SM-J810M'  => array('platform_model' => 'Galaxy J8',                       'platform_year' => 2018),

        /* Samsung Galaxy M series */
        'SM-M105G'  => array('platform_model' => 'Galaxy M10',                      'platform_year' => 2019),
        'SM-M115F'  => array('platform_model' => 'Galaxy M11',                      'platform_year' => 2020),
        'SM-M115M'  => array('platform_model' => 'Galaxy M11',                      'platform_year' => 2020),
        'SM-M205F'  => array('platform_model' => 'Galaxy M20',                      'platform_year' => 2019),
        'SM-M305M'  => array('platform_model' => 'Galaxy M30',                      'platform_year' => 2019),
        'SM-M307F'  => array('platform_model' => 'Galaxy M30s',                     'platform_year' => 2019),
        'SM-M307FN' => array('platform_model' => 'Galaxy M30s',                     'platform_year' => 2019),
        'SM-M315F'  => array('platform_model' => 'Galaxy M31',                      'platform_year' => 2020),

        /* Samsung Galaxy Note series */
        'GT-N5110'  => array('platform_model' => 'Galaxy Note',                     'platform_year' => 2013),
        'GT-N7000'  => array('platform_model' => 'Galaxy Note (3G)',                'platform_year' => 2011),
        'GT-N7003'  => array('platform_model' => 'Galaxy Note (4G)',                'platform_year' => 2011),
        'GT-N7005'  => array('platform_model' => 'Galaxy Note (4G)',                'platform_year' => 2011),
        'GT-N8000'  => array('platform_model' => 'Galaxy Note 10.1 (3G)',           'platform_year' => 2012),
        'GT-N8010'  => array('platform_model' => 'Galaxy Note 10.1',                'platform_year' => 2012),
        'GT-N8013'  => array('platform_model' => 'Galaxy Note 10.1',                'platform_year' => 2012),
        'SM-P600'   => array('platform_model' => 'Galaxy Note 10.1 2014 Edition',   'platform_year' => 2013),
        'SM-P601'   => array('platform_model' => 'Galaxy Note 10.1 2014 Edition',   'platform_year' => 2013),
        'SM-P605'   => array('platform_model' => 'Galaxy Note 10.1 2014 Edition',   'platform_year' => 2013),
        'GT-N7100'  => array('platform_model' => 'Galaxy Note II (3G)',             'platform_year' => 2012),
        'GT-N7105'  => array('platform_model' => 'Galaxy Note II',                  'platform_year' => 2012),
        'SHV-E250S' => array('platform_model' => 'Galaxy Note II',                  'platform_year' => 2012),
        'SM-N900'   => array('platform_model' => 'Galaxy Note 3 (3G)',              'platform_year' => 2013),
        'SM-N900W8' => array('platform_model' => 'Galaxy Note 3',                   'platform_year' => 2013),
        'GT-N9005'  => array('platform_model' => 'Galaxy Note 3',                   'platform_year' => 2013),
        'SM-N9009'  => array('platform_model' => 'Galaxy Note 3',                   'platform_year' => 2013),
        'SM-N900A'  => array('platform_model' => 'Galaxy Note 3',                   'platform_year' => 2013),
        'SM-N900P'  => array('platform_model' => 'Galaxy Note 3',                   'platform_year' => 2013),
        'SM-N900T'  => array('platform_model' => 'Galaxy Note 3',                   'platform_year' => 2013),
        'SM-N900V'  => array('platform_model' => 'Galaxy Note 3',                   'platform_year' => 2013),
        'SM-N9002'  => array('platform_model' => 'Galaxy Note 3 (Dual-SIM)',        'platform_year' => 2013),
        'SM-N9005'  => array('platform_model' => 'Galaxy Note 3 (4G)',              'platform_year' => 2013),
        'SM-N7505'  => array('platform_model' => 'Galaxy Note 3 Neo',               'platform_year' => 2014),
        'SM-N750L'  => array('platform_model' => 'Galaxy Note 3 (LTE-A)',           'platform_year' => 2014),
        'SM-N9100'  => array('platform_model' => 'Galaxy Note 4 Duos',              'platform_year' => 2014),
        'SM-N910A'  => array('platform_model' => 'Galaxy Note 4',                   'platform_year' => 2014),
        'SM-N910C'  => array('platform_model' => 'Galaxy Note 4',                   'platform_year' => 2014),
        'SM-N910F'  => array('platform_model' => 'Galaxy Note 4',                   'platform_year' => 2014),
        'SM-N910H'  => array('platform_model' => 'Galaxy Note 4',                   'platform_year' => 2014),
        'SM-N910P'  => array('platform_model' => 'Galaxy Note 4',                   'platform_year' => 2014),
        'SM-N910T'  => array('platform_model' => 'Galaxy Note 4',                   'platform_year' => 2014),
        'SM-N910V'  => array('platform_model' => 'Galaxy Note 4',                   'platform_year' => 2014),
        'SM-N9106W' => array('platform_model' => 'Galaxy Note 4',                   'platform_year' => 2014),
        'SM-P900'   => array('platform_model' => 'Galaxy Note Pro 12.2',            'platform_year' => 2014),
        'SM-N9200'  => array('platform_model' => 'Galaxy Note 5',                   'platform_year' => 2015),
        'SM-N920C'  => array('platform_model' => 'Galaxy Note 5',                   'platform_year' => 2015),
        'SM-N920F'  => array('platform_model' => 'Galaxy Note 5',                   'platform_year' => 2015),
        'SM-N920I'  => array('platform_model' => 'Galaxy Note 5',                   'platform_year' => 2015),
        'SM-N920T'  => array('platform_model' => 'Galaxy Note 5',                   'platform_year' => 2015),
        'SM-N920V'  => array('platform_model' => 'Galaxy Note 5',                   'platform_year' => 2015),
        'SM-N930T'  => array('platform_model' => 'Galaxy Note 7',                   'platform_year' => 2016),
        'SM-N935F'  => array('platform_model' => 'Galaxy Note FE',                  'platform_year' => 2017),
        'SM-N950'   => array('platform_model' => 'Galaxy Note 8',                   'platform_year' => 2017),
        'SM-N9500'  => array('platform_model' => 'Galaxy Note 8',                   'platform_year' => 2017),
        'SM-N950F'  => array('platform_model' => 'Galaxy Note 8',                   'platform_year' => 2017),
        'SM-N950N'  => array('platform_model' => 'Galaxy Note 8',                   'platform_year' => 2017),
        'SM-N950U'  => array('platform_model' => 'Galaxy Note 8',                   'platform_year' => 2017),
        'SM-N950U1' => array('platform_model' => 'Galaxy Note 8',                   'platform_year' => 2017),
        'SM-N950W'  => array('platform_model' => 'Galaxy Note 8',                   'platform_year' => 2017),
        'SM-N9600'  => array('platform_model' => 'Galaxy Note 9',                   'platform_year' => 2018),
        'SM-N960F'  => array('platform_model' => 'Galaxy Note 9',                   'platform_year' => 2018),
        'SM-N960U'  => array('platform_model' => 'Galaxy Note 9',                   'platform_year' => 2018),
        'SM-N960W'  => array('platform_model' => 'Galaxy Note 9',                   'platform_year' => 2018),
        'SM-N9700'  => array('platform_model' => 'Galaxy Note 10',                  'platform_year' => 2019),
        'SM-N970F'  => array('platform_model' => 'Galaxy Note 10',                  'platform_year' => 2019),
        'SM-N971N'  => array('platform_model' => 'Galaxy Note 10',                  'platform_year' => 2019),
        'SM-N9750'  => array('platform_model' => 'Galaxy Note 10 Plus',             'platform_year' => 2019),
        'SM-N975F'  => array('platform_model' => 'Galaxy Note 10 Plus',             'platform_year' => 2019),
        'SM-N975W'  => array('platform_model' => 'Galaxy Note 10 Plus',             'platform_year' => 2019),
        'SM-N976B'  => array('platform_model' => 'Galaxy Note 10 Plus',             'platform_year' => 2019),
        'SM-N770F'  => array('platform_model' => 'Galaxy Note 10 Lite',             'platform_year' => 2020),
        'SM-N980F'  => array('platform_model' => 'Galaxy Note 20 (Dual-Sim)',       'platform_year' => 2020),
        'SM-N981B'  => array('platform_model' => 'Galaxy Note 20 5G',               'platform_year' => 2020),
        'SM-N985F'  => array('platform_model' => 'Galaxy Note 20 Ultra',            'platform_year' => 2020),
        'SM-N9860'  => array('platform_model' => 'Galaxy Note 20 Ultra 5G',         'platform_year' => 2020),
        'SM-N986B'  => array('platform_model' => 'Galaxy Note 20 Ultra 5G',         'platform_year' => 2020),
        'SM-N986W'  => array('platform_model' => 'Galaxy Note 20 Ultra 5G',         'platform_year' => 2020),

        /* Samsung Galaxy Z Fold/Flip series */
        'SM-F700F'  => array('platform_model' => 'Galaxy Fold',                     'platform_year' => 2019),
        'SM-F900F'  => array('platform_model' => 'Galaxy Fold',                     'platform_year' => 2019),
        'SM-F916B'  => array('platform_model' => 'Galaxy Z Fold2',                  'platform_year' => 2020),
        'SM-F916U1' => array('platform_model' => 'Galaxy Z Fold2 5G',               'platform_year' => 2020),
        'SM-F926B'  => array('platform_model' => 'Galaxy Z Fold 3',                 'platform_year' => 2021),
        'SM-F711B'  => array('platform_model' => 'Galaxy Z Flip 3',                 'platform_year' => 2021),

        /* Samsung Galaxy other series */
        'GT-S5830'  => array('platform_model' => 'Galaxy Ace',                      'platform_year' => 2011),
        'GT-S5839'  => array('platform_model' => 'Galaxy Ace Plus',                 'platform_year' => 2011),
        'GT-S5839I' => array('platform_model' => 'Galaxy Ace Plus',                 'platform_year' => 2011),
        'SM-G357FZ' => array('platform_model' => 'Galaxy Ace 4',                    'platform_year' => 2014),
        'SM-G850F'  => array('platform_model' => 'Galaxy Alpha',                    'platform_year' => 2014),
        'SM-G850W'  => array('platform_model' => 'Galaxy Alpha',                    'platform_year' => 2014),
        'GT-I8262D' => array('platform_model' => 'Galaxy Core Duos',                'platform_year' => 2013),
        'SM-G355H'  => array('platform_model' => 'Galaxy Core 2',                   'platform_year' => 2014),
        'SM-G355HN' => array('platform_model' => 'Galaxy Core 2',                   'platform_year' => 2014),
        'SM-G360F'  => array('platform_model' => 'Galaxy Core Prime',               'platform_year' => 2015),
        'SM-G361F'  => array('platform_model' => 'Galaxy Core Prime',               'platform_year' => 2015),
        'SM-G386F'  => array('platform_model' => 'Galaxy Core 4G',                  'platform_year' => 2014),
        'SM-G386W'  => array('platform_model' => 'Galaxy Core',                     'platform_year' => 2014),
        'GT-S6812'  => array('platform_model' => 'Galaxy Fame Duos',                'platform_year' => 2013),
        'SC-04J'    => array('platform_model' => 'Galaxy Feel',                     'platform_year' => 2017),
        'SGH-N417'  => array('platform_model' => 'Galaxy Feel',                     'platform_year' => 2017),
        'GT-S5660'  => array('platform_model' => 'Galaxy Gio',                      'platform_year' => 2011),
        'GT-S5660M' => array('platform_model' => 'Galaxy Gio',                      'platform_year' => 2011),
        'GT-I9082L' => array('platform_model' => 'Galaxy Grand',                    'platform_year' => 2012),
        'SM-G7102'  => array('platform_model' => 'Galaxy Grand 2',                  'platform_year' => 2014),
        'SM-G7108V' => array('platform_model' => 'Galaxy Grand 2 4G',               'platform_year' => 2014),
        'GT-I9082'  => array('platform_model' => 'Galaxy Grand Duos',               'platform_year' => 2013),
        'GT-I9060'  => array('platform_model' => 'Galaxy Grand Neo',                'platform_year' => 2014),
        'GT-I9060I' => array('platform_model' => 'Galaxy Grand Plus',               'platform_year' => 2014),
        'SM-G530FZ' => array('platform_model' => 'Galaxy Grand Prime',              'platform_year' => 2014),
        'SM-G530H'  => array('platform_model' => 'Galaxy Grand Prime',              'platform_year' => 2014),
        'SM-G530T'  => array('platform_model' => 'Galaxy Grand Prime',              'platform_year' => 2014),
        'SM-G531F'  => array('platform_model' => 'Galaxy Grand Prime',              'platform_year' => 2015),
        'SM-G531H'  => array('platform_model' => 'Galaxy Grand Prime',              'platform_year' => 2015),
        'SM-G532F'  => array('platform_model' => 'Galaxy Grand Prime Plus',         'platform_year' => 2015),
        'GT-I8552'  => array('platform_model' => 'Galaxy Grand Quattro',            'platform_year' => 2013),
        'GT-I8552B' => array('platform_model' => 'Galaxy Grand Quattro',            'platform_year' => 2013),
        'SM-C111'   => array('platform_model' => 'Galaxy K Zoom',                   'platform_year' => 2014),
        'SGH-I527'  => array('platform_model' => 'Galaxy Mega',                     'platform_year' => 2013),
        'GT-I9205'  => array('platform_model' => 'Galaxy Mega 6.3',                 'platform_year' => 2013),
        'SM-B313E'  => array('platform_model' => 'Galaxy Metro 313',                'platform_year' => 2017),
        'SM-G550FY' => array('platform_model' => 'Galaxy On5',                      'platform_year' => 2016),
        'SM-J600DS' => array('platform_model' => 'Galaxy On6',                      'platform_year' => 2018),
        'SM-J600GF' => array('platform_model' => 'Galaxy On6',                      'platform_year' => 2018),
        'SM-G600FY' => array('platform_model' => 'Galaxy On7',                      'platform_year' => 2015),
        'GT-S5302B' => array('platform_model' => 'Galaxy Pocket Duos',              'platform_year' => 2012),
        'SGH-I547'  => array('platform_model' => 'Galaxy Rugby Pro',                'platform_year' => 2012),
        'SM-G350E'  => array('platform_model' => 'Galaxy Star 2 Plus',              'platform_year' => 2014),
        'SM-G130E'  => array('platform_model' => 'Galaxy Star 2 Plus',              'platform_year' => 2014),
        'GT-S7392'  => array('platform_model' => 'Galaxy Trend',                    'platform_year' => 2014),
        'GT-S7560'  => array('platform_model' => 'Galaxy Trend',                    'platform_year' => 2013),
        'GT-S7580'  => array('platform_model' => 'Galaxy Trend+',                   'platform_year' => 2013),
        'GT-S7390'  => array('platform_model' => 'Galaxy Trend lite',               'platform_year' => 2013),
        'GT-S7390G' => array('platform_model' => 'Galaxy Trend lite',               'platform_year' => 2013),
        'SM-G318H'  => array('platform_model' => 'Galaxy Trend 2 lite',             'platform_year' => 2015),
        'GT-S8500'  => array('platform_model' => 'Galaxy Wave',                     'platform_year' => 2010),
        'GT-I8552'  => array('platform_model' => 'Galaxy Win Duos',                 'platform_year' => 2013),
        'SM-G388F'  => array('platform_model' => 'Galaxy Xcover 3',                 'platform_year' => 2015),
        'SM-G389F'  => array('platform_model' => 'Galaxy Xcover 3',                 'platform_year' => 2015),
        'SM-G390F'  => array('platform_model' => 'Galaxy Xcover 4',                 'platform_year' => 2017),
        'SM-G398FN' => array('platform_model' => 'Galaxy Xcover 5',                 'platform_year' => 2019),
        'SM-G715FN' => array('platform_model' => 'Galaxy Xcover Pro',               'platform_year' => 2020),
        'GT-S5360'  => array('platform_model' => 'Galaxy Y',                        'platform_year' => 2011),
        'GT-S6102'  => array('platform_model' => 'Galaxy Y Duos',                   'platform_year' => 2012),
        'GT-S7582'  => array('platform_model' => 'Galaxy S Duos',                   'platform_year' => 2012),
        'SM-G130H'  => array('platform_model' => 'Galaxy Young 2',                  'platform_year' => 2014),
        'SM-G130HN' => array('platform_model' => 'Galaxy Young 2',                  'platform_year' => 2014),
        'SM-Z200F'  => array('platform_model' => 'Galaxy Z2',                       'platform_year' => 2016),

        'Galaxy'    => array('platform_model' => 'Galaxy'),
        'E7'        => array('platform_model' => 'Galaxy E7',                       'platform_year' => 2016),

        /* Samsung non-Galaxy series */
        'GT-E2250'  => array('platform_model' => 'Utica',                           'platform_year' => 2012),
        'GT-E1500'  => array('platform_model' => 'E1500 Duos',                      'platform_year' => 2012),
        'GT-C3590'  => array('platform_model' => 'C3590',                           'platform_year' => 2013,    'system_title' => 'Symbian'),
        'GT-S3800W' => array('platform_model' => 'REX 70',                          'platform_year' => 2013),
        'GT-I8750'  => array('platform_model' => 'Ativ S',                          'platform_year' => 2013),
        'SM-G313HZ' => array('platform_model' => 'Galaxy V',                        'platform_year' => 2014),
        'SM-B350E'  => array('platform_model' => 'Metro B350E',                     'platform_year' => 2015),

        /* Non-regular model names */
        'SCV38'     => array('platform_model' => 'Galaxy S9',                       'platform_year' => 2018),
        'SCV39'     => array('platform_model' => 'Galaxy S9+',                      'platform_year' => 2018),

    );

    /* Check for returning list */
    if ($deviceCode === false)
      return $deviceList;

    /* Initialise result. */
    $result = array(
        'platform_company'  => 'Samsung',
        'platform_country'  => 'kr',
        'platform_model'    => $deviceCode,
        'platform_type'     => 'handheld',
        'platform_format'   => 'handheld',
    );

    /* Check if device is a known device. */
    if (!array_key_exists($deviceCode, $deviceList))
        return $result;

    /* Return result. */
    return array_merge($result, $deviceList[$deviceCode]);
}
?>
